@@ -16,7 +16,7 @@
 # along with this program; if not, write to the Free Software
 # Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA
 
-# Build packages for a specified architecture and upload them packagecloud.io
+# Build packages for a specified architecture and upload them to packagecloud.io
 # Expects the following environment variables to be defined:
 #
 #   ARCH - architecture. 'aarch64', 'x86_64 and 'i386' are currently supported
@@ -49,12 +49,12 @@ PACKPACK_REPO=${PACKPACK_REPO:-akopytov/packpack}
 distros_x86_64=(
     "el 6 x86_64"
     "el 7 x86_64"
-    "fedora 27 x86_64"
     "fedora 28 x86_64"
+    "fedora 29 x86_64"
     "ubuntu trusty x86_64"
     "ubuntu xenial x86_64"
-    "ubuntu artful x86_64"
     "ubuntu bionic x86_64"
+    "ubuntu cosmic x86_64"
     "debian jessie x86_64"
     "debian stretch x86_64"
 )
@@ -62,18 +62,18 @@ distros_x86_64=(
 distros_i386=(
     "ubuntu trusty i386"
     "ubuntu xenial i386"
-    "ubuntu artful i386"
     "ubuntu bionic i386"
+    "ubuntu cosmic i386"
     "debian jessie i386"
     "debian stretch i386"
 )
 
 distros_aarch64=(
     "el 7 aarch64"
-    "fedora 27 aarch64"
     "fedora 28 aarch64"
-    "ubuntu artful aarch64"
+    "fedora 29 aarch64"
     "ubuntu bionic aarch64"
+    "ubuntu cosmic aarch64"
     "ubuntu trusty aarch64"
     "ubuntu xenial aarch64"
     "debian jessie aarch64"
@@ -178,9 +178,12 @@ main()
 
         echo "Pushing packages to ${PACKAGECLOUD_USER}/${PACKAGECLOUD_REPO}"
 
-        package_cloud push ${PACKAGECLOUD_EXTRA_ARGS} \
-                      ${PACKAGECLOUD_USER}/${PACKAGECLOUD_REPO}/${OS}/${DIST} \
-                      $files
+        for f in $files ; do
+            echo $f
+            package_cloud push ${PACKAGECLOUD_EXTRA_ARGS} \
+                          ${PACKAGECLOUD_USER}/${PACKAGECLOUD_REPO}/${OS}/${DIST} \
+                          $f
+        done
 
         OS=${PPOS} packpack/packpack clean
     done
